import { Config } from './Config';
import { P2P as P2PTypes } from '@shardeum-foundation/lib-types';
import { publicKey, secretKey, curvePublicKey, curveSecretKey } from '@shardeum-foundation/lib-crypto-utils';
export interface ArchiverNodeState {
    ip: string;
    port: number;
    publicKey: publicKey;
    secretKey: secretKey;
    curvePk: curvePublicKey;
    curveSk: curveSecretKey;
}
export type ArchiverNodeInfo = Omit<ArchiverNodeState, 'secretKey' | 'curveSk'>;
export declare const joinedArchivers: ArchiverNodeInfo[];
export declare let activeArchivers: ArchiverNodeInfo[];
export declare let activeArchiversByPublicKeySorted: ArchiverNodeInfo[];
export declare let otherArchivers: ArchiverNodeInfo[];
export declare let isFirst: boolean;
export declare let isActive: boolean;
export declare let isSyncing: boolean;
export declare let lastCycleToSync: number;
export declare const archiversReputation: Map<string, string>;
export declare function initFromConfig(config: Config, shutDownMode?: boolean, useArchiverDiscovery?: boolean): Promise<void>;
export declare function exitArchiver(): Promise<void>;
export declare function addSigListeners(sigint?: boolean, sigterm?: boolean): void;
export declare function addArchiver(archiver: ArchiverNodeInfo): void;
export declare function removeActiveArchiver(publicKey: string): void;
export declare function resetActiveArchivers(archivers: ArchiverNodeInfo[]): void;
/**
 * Synchronizes the otherArchivers list to only include archivers that are present in activeArchivers,
 * excluding the current archiver (itself).
 */
export declare function updateOtherArchivers(): void;
export declare function compareCycleRecordWithOtherArchivers(archivers: ArchiverNodeInfo[], ourCycleRecord: P2PTypes.CycleCreatorTypes.CycleRecord): Promise<boolean>;
export declare function getNodeInfo(): ArchiverNodeInfo;
export declare function getSecretKey(): secretKey;
export declare function getCurveSk(): curveSecretKey;
export declare function getCurvePk(): curvePublicKey;
export declare function setActive(): void;
export declare function getRandomArchiver(): ArchiverNodeInfo;
export declare function setSyncing(syncing: boolean): void;
export declare function setLastCycleToSync(cycle: number): void;
