"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.originalTxCheckpointManager = exports.OriginalTxCheckpointBucket = exports.OriginalTxCheckpointRadixDigest = exports.OriginalTxCheckpointRadixEntry = exports.calculateBucketID = exports.OriginalTxCheckpointData = void 0;
const CheckpointData_1 = require("./CheckpointData");
const Crypto = require("../Crypto");
const originalTxsData_1 = require("../dbstore/originalTxsData");
const lib_types_1 = require("@shardeum-foundation/lib-types");
const Logger = require("../Logger");
const Collector_1 = require("../Data/Collector");
class OriginalTxCheckpointData extends CheckpointData_1.CheckpointData {
    constructor(data) {
        const originalTxHash = Crypto.hash(lib_types_1.Utils.safeStringify(data)).toLowerCase();
        super(originalTxHash.substring(0, 2), // address (first 2 chars)
        data.timestamp, // timestamp
        originalTxHash, // hash
        CheckpointData_1.CheckpointType.OriginalTx, // class_type 1 for originalTx
        data // data
        );
    }
}
exports.OriginalTxCheckpointData = OriginalTxCheckpointData;
function calculateBucketID(originalTx) {
    if (!originalTx || originalTx.txId === undefined) {
        Logger.mainLogger.error('Invalid originalTx data');
        throw new Error('Invalid originalTx data');
    }
    return originalTx.cycle.toString();
}
exports.calculateBucketID = calculateBucketID;
//Represents a single radix entry in a bucket
class OriginalTxCheckpointRadixEntry extends CheckpointData_1.CheckpointRadixEntry {
    constructor(radix) {
        super(radix);
    }
}
exports.OriginalTxCheckpointRadixEntry = OriginalTxCheckpointRadixEntry;
//Represents a single radix entry in a bucket
class OriginalTxCheckpointRadixDigest extends CheckpointData_1.CheckpointRadixDigest {
    constructor(radix, hash, itemCount) {
        super(radix, hash, itemCount);
    }
}
exports.OriginalTxCheckpointRadixDigest = OriginalTxCheckpointRadixDigest;
class OriginalTxCheckpointBucket extends CheckpointData_1.CheckpointBucket {
    constructor(startTime, endTime, bucketID, validateData, updateData) {
        super(startTime, endTime, bucketID, validateData, updateData, CheckpointData_1.CheckpointType.OriginalTx);
    }
    async update(currentTime) {
        // Call parent update first
        super.update(currentTime);
    }
}
exports.OriginalTxCheckpointBucket = OriginalTxCheckpointBucket;
class OriginalTxCheckpointManager extends CheckpointData_1.CheckpointBucketManager {
    constructor() {
        const persistenceCallbacks = {
            validateData,
            updateData,
        };
        super(persistenceCallbacks, CheckpointData_1.CheckpointType.OriginalTx);
    }
    static getInstance() {
        if (!OriginalTxCheckpointManager.instance) {
            OriginalTxCheckpointManager.instance = new OriginalTxCheckpointManager();
        }
        return OriginalTxCheckpointManager.instance;
    }
}
// Define the updateData function
async function updateData(data) {
    try {
        // Insert/Update into originalTxsData table
        const originalTx = data.d;
        // Avg entry size is about 860 bytes
        await (0, originalTxsData_1.insertOriginalTxData)(originalTx, false);
    }
    catch (err) {
        Logger.mainLogger.error('Failed to store originalTx checkpoint data:', err);
        throw err;
    }
}
// Define the validateData function
async function validateData(data) {
    // Reuse existing validation logic
    return (0, Collector_1.validateOriginalTxDataSchema)(data.d);
}
// Export the singleton instance
exports.originalTxCheckpointManager = OriginalTxCheckpointManager.getInstance();
//# sourceMappingURL=OriginalTxsData.js.map