"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const path_1 = require("path");
const dbstore = require("./dbstore");
const txDigesterDB = require("./txDigester/index");
const Config_1 = require("./Config");
const Crypto = require("./Crypto");
const lib_types_1 = require("@shardeum-foundation/lib-types");
const fs_1 = require("fs");
const path_2 = require("path");
const Logger = require("./Logger");
const saveConsoleOutput_1 = require("./saveConsoleOutput");
const fastify_1 = require("fastify");
const cors_1 = require("@fastify/cors");
const rate_limit_1 = require("@fastify/rate-limit");
const api_1 = require("./txDigester/api");
const configFile = (0, path_1.join)(process.cwd(), 'archiver-config.json');
const start = async () => {
    (0, Config_1.overrideDefaultConfig)(configFile);
    const hashKey = Config_1.config.ARCHIVER_HASH_KEY;
    Crypto.setCryptoHashKey(hashKey);
    let logsConfig;
    try {
        logsConfig = lib_types_1.Utils.safeJsonParse((0, fs_1.readFileSync)((0, path_2.resolve)(__dirname, '../archiver-log.json'), 'utf8'));
    }
    catch (err) {
        console.log('Failed to parse archiver log file:', err);
    }
    const logDir = `${Config_1.config.ARCHIVER_LOGS}/txDigesterAPI`;
    const baseDir = '.';
    logsConfig.dir = logDir;
    Logger.initLogger(baseDir, logsConfig);
    if (logsConfig.saveConsoleOutput) {
        (0, saveConsoleOutput_1.startSaving)((0, path_1.join)(baseDir, logsConfig.dir));
    }
    await dbstore.initializeDB(Config_1.config);
    await txDigesterDB.initializeDB(Config_1.config);
    console.log('Starting txDigest API server....');
    const server = (0, fastify_1.default)({
        logger: false,
    });
    await server.register(cors_1.default);
    await server.register(rate_limit_1.default, {
        global: true,
        max: Config_1.config.RATE_LIMIT,
        timeWindow: 10,
        allowList: ['127.0.0.1', '0.0.0.0'], // Excludes local IPs from rate limits
    });
    server.addContentTypeParser('application/json', { parseAs: 'string' }, (req, body, done) => {
        try {
            const jsonString = typeof body === 'string' ? body : body.toString('utf8');
            done(null, lib_types_1.Utils.safeJsonParse(jsonString));
        }
        catch (err) {
            err.statusCode = 400;
            done(err, undefined);
        }
    });
    server.setReplySerializer((payload) => {
        return lib_types_1.Utils.safeStringify(payload);
    });
    // Register API routes
    (0, api_1.registerRoutes)(server);
    // Start server and bind to port on all interfaces
    server.listen({
        port: Config_1.config.txDigest.apiServerPort,
        host: '0.0.0.0',
    }, (err) => {
        Logger.mainLogger.debug('TXDigestAPI Listening', Config_1.config.txDigest.apiServerPort);
        if (err) {
            server.log.error(err);
            process.exit(1);
        }
        Logger.mainLogger.debug('txDigestAPI server has started.');
    });
};
start();
//# sourceMappingURL=txDigestAPIserver.js.map