"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.verifyPayload = exports.initAjvSchemas = void 0;
const lib_types_1 = require("@shardeum-foundation/lib-types");
const SchemaHelpers_1 = require("../../utils/serialization/SchemaHelpers");
const Receipts_1 = require("./Receipts");
const Accounts_1 = require("./Accounts");
const OriginalTxData_1 = require("./OriginalTxData");
function initAjvSchemas() {
    (0, Accounts_1.initAccounts)();
    (0, Receipts_1.initReceipts)();
    (0, OriginalTxData_1.initOriginalTxData)();
}
exports.initAjvSchemas = initAjvSchemas;
function verifyPayload(name, payload) {
    const verifyFn = (0, SchemaHelpers_1.getVerifyFunction)(name);
    const isValid = verifyFn(payload);
    if (!isValid) {
        return parseAjvErrors(verifyFn.errors);
    }
    else {
        return null;
    }
}
exports.verifyPayload = verifyPayload;
function parseAjvErrors(errors) {
    if (!errors)
        return null;
    return errors.map((error) => {
        let errorMsg = `${error.message}`;
        if (error.params && Object.keys(error.params).length > 0) {
            errorMsg += `: ${lib_types_1.Utils.safeStringify(error.params)}`;
        }
        return errorMsg;
    });
}
//# sourceMappingURL=Helpers.js.map